@@ -1,12 +1,20 @@
 import abc
+import logging
 import subprocess
-
-from typing import List, Dict, Optional, Set, Type
-from os.path import join as path_join
+import sys
 from os.path import exists as path_exists
 from os.path import expanduser
-import sys
-import logging
+from os.path import join as path_join
+from typing import Dict, List, Optional, Set, Type
+
+if sys.version_info[0] == 2:  # Python 2
+
+    class ABC(object):
+        __meta_class__ = abc.ABCMeta
+        __slots__ = ()
+
+else:
+    ABC = abc.ABC
 
 _logger = logging.getLogger("install_addons")
 handler = logging.StreamHandler()
@@ -45,7 +53,7 @@ class AddonsRegistry(object):
         return None
 
 
-class OdooAddonsDef(abc.ABC):
+class OdooAddonsDef(ABC):
     def __init__(self, name):
         self.name = name
 
@@ -91,7 +99,8 @@ class AddonsInstaller:
             _logger.debug("No package.json founded in %s", path_npm)
 
     @staticmethod
-    def install(git_addons: OdooAddonsDef):
+    def install(git_addons):
+        # type: (OdooAddonsDef) -> None
         _logger.info("install %s", git_addons)
         try:
             AddonsInstaller.exec_cmd(git_addons.install_cmd())
@@ -133,7 +142,7 @@ class KeySuffix(object):
         return "%s(%s, default=%s)" % (type(self).__name__, self.full_key, self.default_key)
 
 
-class AddonsSuffix(abc.ABC):
+class AddonsSuffix(ABC):
     ADDONS_DEFAULT = "DEFAULT"
     ADDONS_SUFFIX_EXCLUDE = "EXCLUDE"
 
@@ -220,6 +229,8 @@ class GitOdooAddons(AddonsSuffix):
             self.branch = branch
             if not clone_path:
                 clone_path = path_join("/", "opt", "addons", git_path.lower())
+            if not clone_path:
+                clone_path = path_join(clone_path, git_path.lower())
             self.clone_path = expanduser(clone_path)
             self.pull_options = pull_options
             self.https_login = https_login
@@ -259,6 +270,7 @@ class GitOdooAddons(AddonsSuffix):
     def extract(self, env_vars):
         # type: (Dict[str, str]) -> GitOdooAddons.Result
         res = self.to_dict(env_vars)
+        # Remove de '/' at the end and the beginning of the name '/p1/p2' become 'p1/p2'
         if not res[self.SERVER]:
             raise ValueError(
                 "Not git server is provided, key [%s] or [%s]" % (self.SERVER.full_key, self.SERVER.default_key)
@@ -267,8 +279,10 @@ class GitOdooAddons(AddonsSuffix):
         if res[self.PROTOCOLE] not in self.FORMAT_GIT_CLONE.keys():
             raise ValueError(
                 "The selected protocole %s is not supported, possible values are %s"
-                % (res[self.PROTOCOLE], list(self.FORMAT_GIT_CLONE.keys()))
+                % (res[self.PROTOCOLE], sorted(list(self.FORMAT_GIT_CLONE.keys())))
             )
+
+        res[self.NAME] = res[self.NAME].strip("/")
         if self.PROTOCLE_SSH == res[self.PROTOCOLE]:
             raise ValueError("Protocole [%s] not supported for the moment" % self.PROTOCLE_SSH)
         else:
@@ -294,9 +308,11 @@ class GitOdooAddons(AddonsSuffix):
         else:
             res.pop(self.HTTPS_LOGIN, False)
             res.pop(self.HTTPS_PASSWORD, False)
-
+        if self.CLONE_PATH.default_key in env_vars and self.CLONE_PATH.full_key not in env_vars:
+            # If default key in env_vars but not dedicated key then we add identifier in lower case to the clone path
+            res[self.CLONE_PATH] = path_join(res[self.CLONE_PATH], self.identifier.lower())
         return GitOdooAddons.Result(
-            name=self.NAME.full_key,
+            name=self.identifier,
             git_path=res[self.NAME],
             branch=res[self.BRANCH],
             clone_path=res[self.CLONE_PATH],
@@ -335,7 +351,7 @@ class LocalOdooAddons(AddonsSuffix):
             self.full_path = full_path
 
 
-class ABCSubDirAddons(AddonsSuffix, abc.ABC):
+class ABCSubDirAddons(AddonsSuffix, ABC):
     _identifier = None
 
     def __init__(self, base_key):
